@@ -1657,7 +1657,7 @@ describe("assert", function() {
                     color.green("1") +
                     " \n" +
                     "3\n" +
-                    "hey"
+                    '"hey"'
             );
         });
 
@@ -1674,13 +1674,13 @@ describe("assert", function() {
                     color.green("1") +
                     " \n" +
                     "3\n" +
-                    "hey\n" +
+                    '"hey"\n' +
                     "Call 2:\n" +
                     "1\n" +
                     "3\n" +
-                    color.red("not") +
+                    color.red('"not"') +
                     " " +
-                    color.green("hey") +
+                    color.green('"hey"') +
                     " "
             );
         });
@@ -1892,7 +1892,7 @@ describe("assert", function() {
                     color.green("4") +
                     " \n" +
                     "3\n" +
-                    "hey"
+                    '"hey"'
             );
         });
 
@@ -1907,13 +1907,13 @@ describe("assert", function() {
                     "1\n" +
                     color.red("3") +
                     " " +
-                    color.green("hey") +
+                    color.green('"hey"') +
                     " \n" +
-                    color.red("hey") +
+                    color.red('"hey"') +
                     "\n" +
                     "Call 2:\n" +
                     "1\n" +
-                    "hey"
+                    '"hey"'
             );
         });
 
@@ -1928,13 +1928,13 @@ describe("assert", function() {
                     "1\n" +
                     color.red("3") +
                     " " +
-                    color.green("hey") +
+                    color.green('"hey"') +
                     " \n" +
-                    color.red("hey") +
+                    color.red('"hey"') +
                     "\n" +
                     "Call 2:\n" +
                     "1\n" +
-                    "hey"
+                    '"hey"'
             );
         });
 
@@ -1943,7 +1943,7 @@ describe("assert", function() {
 
             assert.equals(
                 this.message("calledWithExactly", this.obj.doSomething, 1, 3).replace(/ at.*/g, ""),
-                "expected doSomething to be called with exact arguments \n1\n3\n" + color.red("hey")
+                "expected doSomething to be called with exact arguments \n1\n3\n" + color.red('"hey"')
             );
         });
 
@@ -1962,7 +1962,7 @@ describe("assert", function() {
                     color.green("1") +
                     " \n" +
                     "3\n" +
-                    "bob"
+                    '"bob"'
             );
 
             this.obj.doSomething();
@@ -1974,12 +1974,25 @@ describe("assert", function() {
                     "\n" +
                     color.red("3") +
                     "\n" +
-                    color.red("bob") +
+                    color.red(JSON.stringify('"bob"')) +
                     "\n" +
                     "Call 2:"
             );
         });
 
+        it("assert.calledWith exception message with equal string representations", function() {
+            this.obj.doSomething(1234);
+
+            assert.equals(
+                this.message("calledWith", this.obj.doSomething, "1234"),
+                "expected doSomething to be called with arguments \n" +
+                    color.red(1234) +
+                    " " +
+                    color.green('"1234"') +
+                    " "
+            );
+        });
+
         it("assert.alwaysCalledWithExactly exception message", function() {
             this.obj.doSomething(1, 3, "hey");
             this.obj.doSomething(1, 3);
@@ -1990,7 +2003,7 @@ describe("assert", function() {
                     "Call 1:\n" +
                     "1\n" +
                     "3\n" +
-                    color.red("hey") +
+                    color.red('"hey"') +
                     "\n" +
                     "Call 2:\n" +
                     "1\n" +
